=======================
Feature Flag Server SDK
=======================


.. image:: https://img.shields.io/pypi/v/ff_python_server_sdk.svg
        :target: https://pypi.python.org/pypi/ff_python_server_sdk

.. image:: https://img.shields.io/travis/drone/ff_python_server_sdk.svg
        :target: https://travis-ci.com/drone/ff_python_server_sdk

.. image:: https://readthedocs.org/projects/ff-python-server-sdk/badge/?version=latest
        :target: https://ff-python-server-sdk.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/drone/ff_python_server_sdk/shield.svg
     :target: https://pyup.io/repos/github/drone/ff_python_server_sdk/
     :alt: Updates



Feature flag server SDK for python


* Free software: Apache Software License 2.0
* Documentation: https://harness-featureflags.readthedocs.io.

